package com.sk.newsplayer;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.text.Html;
import android.text.TextUtils;
import android.text.method.ScrollingMovementMethod;
import android.view.Menu;
import android.view.View;
import android.widget.ImageButton;
import android.widget.TextView;
import android.widget.Toast;

import com.sk.newsplayer.model.NewsItem;
import com.sk.newsplayer.service.AbsNewsDocTask;
import com.sk.newsplayer.service.AudioDownloader;
import com.sk.newsplayer.service.AudioPlayService;
import com.sk.newsplayer.service.NewsScriptTask;
import com.sk.newsplayer.util.AppUtils;
import com.sk.newsplayer.util.LogUtils;

public class NewsPlayActivity extends Activity implements AbsNewsDocTask.NewsListListener<String>, DialogInterface.OnClickListener {
	
	private static final String TAG = NewsPlayActivity.class.getSimpleName();
	
	private TextView mTitleText, mDateText, mScriptText;
	private ImageButton mFFwdButton, mFwdButton, mPlayButton, mRwdButton, mFRwdButton;
	
	private NewsItem mNewsItem;
	
	private PlaServiceReceiver mPlayReceiver;
	
	private class PlaServiceReceiver extends BroadcastReceiver{
		@Override
		public void onReceive(Context context, Intent intent) {
			String action = intent.getAction();
			
			if (action==null) return;
			 
			if (AudioPlayService.ACTION_POSITION_CHANGED.equals(action)){
				
			}
			
		}
		
	};
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_play);
        
        setup();
    }

    @Override
	protected void onResume() {
		super.onResume();
		
		waitForService();
	}

	@Override
	protected void onPause() {
		super.onPause();
		
		if (mPlayReceiver!=null)
			unregisterReceiver(mPlayReceiver);
	}

	@Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }

	@Override
	public void onDone(String result) {
		mNewsItem.script = result;
		display();
		//mScriptText.setText(Html.fromHtml(mNewsItem.script));
	}
	
	public void onButtonClick(View view){
		switch (view.getId()){
			case R.id.fForwardButton:
				break;
			case R.id.forwardButton:
				break;
			case R.id.playButton:
				doPlay();
				break;
			case R.id.rewindButton:
				break;
			case R.id.fRewindButton:
				break;
		}
	}

	@Override
	public void onClick(DialogInterface dialogInterface, int which) {
		downloadAudio();
	}

	/**
	 * Download audio if it does not exist otherwise send reuqst to play it to AudioPlayService.
	 */
	private void doPlay() {
		if (!mNewsItem.fileExists() && !TextUtils.isEmpty(mNewsItem.audioLink)){
			AppUtils.showYesNoDialog(this, "Do you want to download audio?", this);
			return;
		}
		
		Intent intent = new Intent(this, AudioPlayService.class);
		intent.setAction(AudioPlayService.ACTION_PLAY);
		intent.putExtra(AudioPlayService.EXTRA_ITEM, mNewsItem);
		startService(intent);
	}

	private void setup() {
		mTitleText = (TextView)findViewById(R.id.titleText);
		mDateText = (TextView)findViewById(R.id.dateText);
		mScriptText = (TextView)findViewById(R.id.scriptText);
		//Make a script TextView scrollable
		mScriptText.setMovementMethod(new ScrollingMovementMethod());
		
		mFFwdButton = (ImageButton)findViewById(R.id.fForwardButton);
		mFwdButton 	= (ImageButton)findViewById(R.id.forwardButton);
		mPlayButton = (ImageButton)findViewById(R.id.playButton);
		mRwdButton 	= (ImageButton)findViewById(R.id.rewindButton); 
		mFRwdButton = (ImageButton)findViewById(R.id.fRewindButton);
		
		mNewsItem = getIntent().getParcelableExtra(AudioPlayService.EXTRA_ITEM);
		if (mNewsItem == null) return;
		
		//mTitleText.setText(mNewsItem.title);
		//mDateText.setText(mNewsItem.lastUpdated);
		//mScriptText.setText(mNewsItem.script);
		display();
		if (TextUtils.isEmpty(mNewsItem.script) && !TextUtils.isEmpty(mNewsItem.moreLink)){
			NewsScriptTask task = new NewsScriptTask(this);
			task.setListener(this).execute(mNewsItem.moreLink);
		}
	}
	
	private void waitForService(){
		mPlayReceiver = new PlaServiceReceiver();

		IntentFilter filter = new IntentFilter(AudioPlayService.ACTION_POSITION_CHANGED);
		filter.addAction(AudioPlayService.ACTION_POSITION_CHANGED);
		filter.addAction(AudioPlayService.ACTION_AB_REPEAT);
		filter.addAction(AudioPlayService.ACTION_REPEAT_MODE_CHANGED);
		filter.addAction(AudioPlayService.ACTION_NEXT_NEWS);
		registerReceiver(mPlayReceiver, filter);
	}
	
	private void display(){
		mTitleText.setText(mNewsItem.title);
		mDateText.setText(mNewsItem.lastUpdated);
		mScriptText.setText(Html.fromHtml(mNewsItem.script));
	}
	
	private void downloadAudio(){
		AudioDownloader downloader = new AudioDownloader(this, new AudioDownloader.DownloadListener() {
			//ProgressDialog progress;
			
			@Override
			public void onStart() {
				//progress = ProgressDialog.show(NewsPlayActivity.this, "Getting audio file", "Wait for a minute.");
				LogUtils.d(TAG, "Download Start for audio:" + mNewsItem.audioLink);
			}
			
			@Override
			public void onFinish(int errorCode, String result) {
				
				//if (progress!=null)
				//	progress.dismiss();
				
				String message = ""+result;
				if (errorCode !=0) {
					mNewsItem.filePath = result;
					Toast.makeText(NewsPlayActivity.this, message, Toast.LENGTH_SHORT).show();
					return;
				}
				
				Intent intent = new Intent(NewsPlayActivity.this, AudioPlayService.class);
				intent.setAction(AudioPlayService.ACTION_PLAY);
				intent.putExtra(AudioPlayService.EXTRA_ITEM, mNewsItem);
				startService(intent);
			}
		});
		
		//downloader.setPath("com.sk.newsplayer").download(mNewsItem.audioLink);
		downloader.download(mNewsItem.audioLink);
	}

}
