package com.sk.newsplayer.model;

import java.io.File;

import android.database.Cursor;
import android.os.Parcel;
import android.os.Parcelable;
import android.text.TextUtils;
import android.view.View;

public class NewsItem implements Parcelable {
	
	public enum DownloadStatus{None, Downloading, Done, Error};
	
	private static final long serialVersionUID = 1L;
	
	public static final int NONE 		= View.INVISIBLE;
	public static final int PROGRESS 	= View.VISIBLE;
	public static final int DONE 		= View.GONE;
	
	public String icon = "";			//icon resource id
	public long _id = 0;			//sqlite id
	public String newsId = "";		//news id
	public String sysDate = "";		//system date time
	public String lastUpdated = "";	//news date time
	public String title = "";		//news title
	public String reporter = "";		//reporter name
	public String moreLink = "";		//link for script
	public String audioLink = "";	//mp3 file link
	public String playTime = "";		//Audio playing time (minutes)
	public String summary = "";		//News summary
	public String script = "";		//content
	public String filePath = "";		//audio link
	public int status = NONE;	//
	
	public NewsItem() {
		// TODO Auto-generated constructor stub
	}
	

	@Override
	public String toString() {
		return "NewsItem [icon=" + icon + ", _id=" + _id + ", articleId="
				+ newsId + ", sysDate=" + sysDate + ", lastUpdated="
				+ lastUpdated + ", title=" + title + ", reporter=" + reporter
				+ ", moreLink=" + moreLink + ", audioLink=" + audioLink
				+ ", playTime=" + playTime + ", summary=" + summary.length()
				+ ", script=" + script.length() + ", filePath=" + filePath + ", status="
				+ status + "]";
	}


	public int describeContents() {
		return 0;
	}
	
	public boolean fileExists(){
		if (TextUtils.isEmpty(filePath))
			return false;
		
		File file = new File(filePath);
		return file.exists();
	}
	
	public void setFilePath(String value){
		status = NewsItem.NONE;
		this.filePath = value;
		if (fileExists())
			status = NewsItem.DONE;
	}
	
	public void writeToParcel(Parcel out, int flags) {
		out.writeString(icon);
		out.writeLong(_id);
		out.writeString(newsId);
		out.writeString(sysDate);
		out.writeString(lastUpdated);
		out.writeString(title);
		out.writeString(reporter);
		out.writeString(moreLink);
		out.writeString(audioLink);
		out.writeString(playTime);
		out.writeString(summary);
		out.writeString(script);
		out.writeString(filePath);
		out.writeInt(status);
	}
	
	public static final Parcelable.Creator<NewsItem> CREATOR = new Parcelable.Creator<NewsItem>() {
		public NewsItem createFromParcel(Parcel in) {
		    return new NewsItem(in);
		}
		
		public NewsItem[] newArray(int size) {
		    return new NewsItem[size];
		}
	};
	
	private NewsItem(Parcel in) {
		icon 		= in.readString();
		_id			= in.readLong();
		newsId		= in.readString();
		sysDate		= in.readString();
		lastUpdated = in.readString();
		title		= in.readString();
		reporter	= in.readString();
		moreLink	= in.readString();
		audioLink	= in.readString();
		playTime	= in.readString();
		summary		= in.readString();
		script		= in.readString();
		filePath	= in.readString();
		status		= in.readInt();
	}
	
	public static NewsItem getRecord(Cursor c){
		NewsItem item = new NewsItem();
		item._id 		= c.getLong(c.getColumnIndex("_id"));
		item.newsId 	= c.getString(c.getColumnIndex("newsId"));
		item.sysDate 	= c.getString(c.getColumnIndex("sysDate"));
		item.lastUpdated= c.getString(c.getColumnIndex("lastUpdated"));
		item.title		= c.getString(c.getColumnIndex("title"));
		item.playTime  	= c.getString(c.getColumnIndex("playTime"));
		item.reporter  	= c.getString(c.getColumnIndex("reporter"));
		item.moreLink	= c.getString(c.getColumnIndex("moreLink"));
		item.audioLink 	= c.getString(c.getColumnIndex("audioLink"));
		item.summary	= c.getString(c.getColumnIndex("summary"));
		item.script		= c.getString(c.getColumnIndex("script"));
		item.filePath	= c.getString(c.getColumnIndex("filePath"));
		item.status 	= NewsItem.NONE;
		if (item.fileExists())
			item.status = NewsItem.DONE;
		
		return item;
	}
}
