package com.sk.newsplayer.service;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import android.app.ProgressDialog;
import android.content.Context;

import com.sk.newsplayer.model.NewsItem;
import com.sk.newsplayer.util.LogUtils;

/**
 * URL: http://searchmp3.mobi
 * Class to search and get list of music for free download
 * @author sunghun
 *
 */
public class MusicSearchTask extends AbsNewsDocTask<List<NewsItem>>{

	public MusicSearchTask(Context context) {
		super(context);
	}

	private static final String TAG = MusicSearchTask.class.getSimpleName();
	
	ProgressDialog mProgress = null;

	@Override
	protected void onPreExecute() {
		super.onPreExecute();
		
		mProgress = ProgressDialog.show(this.mContext, "Searching music", "Wait a moment.");
	}

	@Override
	protected void onPostExecute(List<NewsItem> result) {
		super.onPostExecute(result);
		
		if (mProgress!=null)
			mProgress.dismiss();
	}

	@Override
	protected List<NewsItem> getData(String aUrl) {
		
	    try {
	    	URL url = new URL(aUrl);
	    	HttpURLConnection conn = (HttpURLConnection)url.openConnection();
	    	conn.connect();
	    	
	    	BufferedReader br = new BufferedReader(new InputStreamReader(conn.getInputStream()));
			StringBuffer sb = new StringBuffer();
			String line = null;
			while ((line=br.readLine())!=null){
				sb.append(line);
			}
	    	br.close();
	    	
	    	LogUtils.d(TAG, "content===>" + sb.toString());
	    	LogUtils.d(TAG, "length====>" + sb.toString().length());
	    } catch (IOException e) {
	        // Could provide a more explicit error message for IOException or IllegalStateException
	        LogUtils.e(TAG, "Error while getting data:" + e.getMessage());
	    } 
	    
	    return new ArrayList<NewsItem>();
	    
	}

	@Override
	protected List<NewsItem> parse(Document doc) {
		List<NewsItem> items = new ArrayList<NewsItem>();
		if (doc==null) return items;
		
		LogUtils.d(TAG, "doc.html.length:" + doc.html().length());
		
		Elements itemsList = doc.select("#content>div.wrapper ul li");
		LogUtils.d(TAG, "itemsList.size:" + itemsList.size());
    	for (Element item : itemsList){
    		//LogUtils.d(TAG, "item.html:" + item.html());
    		Elements anchor 	 = item.select("a");	
    		String moreLink 	 = anchor.attr("href");//download link
    		Elements image 		 = item.select("a img");
    		//LogUtils.d(TAG, "ima	ge.html:" + item.select("a").html());
    		Element title 		 = anchor.last();//select(".item-title");
    		
    		NewsItem newsItem 	 = new NewsItem();
    		//newsItem.newsId      = item.id();
    		//newsItem.icon		 = image.attr("src");
    		newsItem.title 		 = title.text();
    		newsItem.moreLink    = moreLink;
   		
    		items.add(newsItem);
    		
    		//LogUtils.d(TAG, "" + newsItem);
    	}
    	
    	return items;
	}

}
