package com.sk.newsplayer.service;

import java.util.ArrayList;
import java.util.List;

import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import android.app.ProgressDialog;
import android.content.Context;

import com.sk.newsplayer.model.NewsItem;
import com.sk.newsplayer.util.LogUtils;

/**
 * Class to get list of ABC News
 * @author sunghun
 *
 */
public class NewsListTask extends AbsNewsDocTask<List<NewsItem>>{

	public NewsListTask(Context context) {
		super(context);
	}

	private static final String TAG = NewsListTask.class.getSimpleName();
	
	ProgressDialog mProgress = null;

	@Override
	protected void onPreExecute() {
		super.onPreExecute();
		
		mProgress = ProgressDialog.show(this.mContext, "Downloading", "Wait a moment.");
	}

	@Override
	protected void onPostExecute(List<NewsItem> result) {
		super.onPostExecute(result);
		
		if (mProgress!=null)
			mProgress.dismiss();
	}



	@Override
	protected List<NewsItem> parse(Document doc) {
		List<NewsItem> items = new ArrayList<NewsItem>();
		if (doc==null) return items;
		
		Elements storyTeasers = doc.select(".story-teaser");
    	
    	for (Element item : storyTeasers){
    		Elements date 	 = item.select(".main>div.date");
    		Elements title 	 = item.select(".main>h4>a");
    		Elements summary = item.select(".main>p");
    		Elements storyPlayer = item.select("div.storyplayer>a");
    		
    		NewsItem newsItem = new NewsItem();
    		newsItem.newsId      = item.id();
    		newsItem.lastUpdated = date.text();
    		newsItem.title 		= title.text();
    		newsItem.summary 	= summary.text();
    		newsItem.moreLink   = title.attr("href");
    		newsItem.audioLink  = storyPlayer.attr("href");
    		
    		items.add(newsItem);
    		
    		LogUtils.d(TAG, "" + newsItem);
    	}
    	
    	return items;
	}

}
