package com.sk.newsplayer.util;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.ContentResolver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.database.Cursor;
import android.net.Uri;
import android.os.IBinder;
import android.provider.MediaStore;
import android.provider.Settings.Secure;
import android.text.TextUtils;
import android.view.Window;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.Toast;

public class AppUtils {
	
	public static Context context = null;

	public static enum MsgType {
		DEFAULT, INFO, WARINING, ERROR;
	}

	public static String getVersionName(String prefix){
		PackageInfo packageInfo;
		try {
			packageInfo = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
			String result = TextUtils.isEmpty(prefix) ? "" : prefix + "-";
			result += packageInfo.versionName;
			
			return result;
		} catch (NameNotFoundException e) {
			e.printStackTrace();
		}
		
		return "Unknown";
	}

	/**
	 * @param id
	 * @return
	 */
	public static String getResStr(int id)
	{
		return context.getResources().getString(id);
	}
	
	public static Toast toast(String msg){
		Toast toast = Toast.makeText(context, msg, Toast.LENGTH_SHORT);
		toast.show();
		return toast;
	}

	public static Toast toastResStr(int resId){
		Toast toast = Toast.makeText(context, resId, Toast.LENGTH_SHORT);
		toast.show();
		return toast;
	}
	
	/**
	 * @param msg
	 */
	public static void alert(Context context, String title, String msg)
	{
		int iconId = 0;
		AlertDialog.Builder dlg = new AlertDialog.Builder(context);		
		dlg.setMessage(msg);
		dlg.setPositiveButton(getResStr(android.R.string.ok), null);		
		dlg.setTitle(title);		
		dlg.setIcon(iconId);		
		dlg.create();
		dlg.show();
	}

	/**
	 * Show message box string of i. Don't confuse this parameter as resource id.
	 * @param i
	 */
//	public static void alert(int i)
//	{
//		Integer ii = i;
//		alert(ii.toString());
//	}
	
	/**
	 * @param resId
	 */
	public static void alertResStr(Context context, int titleId, int msgId)
	{
		alert(context, getResStr(titleId), getResStr(msgId));
	}

	/**
	 * @param msg
	 * @param msgType
	 */
	public static void showMsg(Context context, String title, String msg, AppUtils.MsgType msgType)
	{
		//String sTitle = "";//getResStr(R.string.app_name);
		int iconId = 0;
		
		switch (msgType){
			case INFO:
				//sTitle = "Info";
				iconId = android.R.drawable.ic_dialog_info;// R.drawable.msgicon_info;
				break;
			
			case WARINING:
				//sTitle = "Warning";
				iconId = android.R.drawable.ic_dialog_alert; //R.drawable.msgicon_warning;
				break;
				
			case ERROR:
				//sTitle = "Error";
				iconId = android.R.drawable.ic_dialog_alert; //R.drawable.msgicon_error;
				break;
		}
		
		AlertDialog.Builder dlg = new AlertDialog.Builder(context);		
		dlg.setMessage(msg);
		dlg.setPositiveButton(android.R.string.ok, null);		
		dlg.setTitle(title);		
		dlg.setIcon(iconId);		
		dlg.create();
		dlg.show();
	}	

	/**
	 * @param msg
	 */
	public static AlertDialog showYesNoDialog(Context context, String msg, DialogInterface.OnClickListener yesClickListener)
	{
		String sTitle = "Confirm";
		int iconId = android.R.drawable.ic_menu_help;
		
		AlertDialog.Builder dlg = new AlertDialog.Builder(context);		
		dlg.setMessage(msg);
		dlg.setPositiveButton(android.R.string.yes, yesClickListener);		
		dlg.setNegativeButton(android.R.string.no, new DialogInterface.OnClickListener() {
			@Override
			public void onClick(DialogInterface dialog, int which) {
				dialog.dismiss();
			}
		});
		dlg.setTitle(sTitle);		
		dlg.setIcon(iconId);		
		dlg.create();
		return dlg.show();
	}
	
	public static AlertDialog showYesNoDialog(Context context, int msgId,  DialogInterface.OnClickListener yesClickListener)
	{
		return showYesNoDialog(context, getResStr(msgId), yesClickListener);
	}	
	
	/**
	 * @param resId
	 * @param msgType
	 */
	public static void showMsgResStr(Context context, int titleResId, int resId, AppUtils.MsgType msgType)
	{
		showMsg(context, getResStr(titleResId), getResStr(resId), msgType);
	}
	
	/**
	 * Execute different app eg)Calendar runApp("au.org.jeenee.android.calendar", "au.org.jeenee.android.calendar.CalendarMain")
	 */
	public static boolean runApp(Context context, String packageName, String mainActivityName){
		PackageManager pm = context.getPackageManager();
		
		try {
			Intent intent = pm.getLaunchIntentForPackage(packageName);
			if (intent==null){
				return false;
			}
			
			intent.setClassName(packageName, mainActivityName);
			context.startActivity(intent);
			return true;
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		return false;
	}
	
	/**
	 * @return
	 */
	public static String getAndroidId(){
		return Secure.getString(context.getContentResolver(), Secure.ANDROID_ID);
	}
	
	/**
	 * Enables to use ITelephony, which is able to controll call in Android.
	 * @return
	 */
	/*
	public static com.android.internal.telephony.ITelephony getTelephonyService() {
		com.android.internal.telephony.ITelephony telephony = null;
        TelephonyManager tm = (TelephonyManager) context.getSystemService(Context.TELEPHONY_SERVICE);
        try {
            // Java reflection to gain access to TelephonyManager's
            // ITelephony getter
            //Log.v(TAG, "Get getTeleService...");
            Class<?> c = Class.forName(tm.getClass().getName());
            Method m = c.getDeclaredMethod("getITelephony");
            m.setAccessible(true);
            
            telephony = (ITelephony) m.invoke(tm);
            
        } catch (Exception e) {
            e.printStackTrace();
            //Log.e(TAG,
            //        "FATAL ERROR: could not connect to telephony subsystem");
            JLogUtils.e("JAapUtils", "Exception object: " + e);
        }
        
        return telephony;
	}
	*/
	//Hide notification bar prgramtically
	public static void hideNotificationBar(Activity activity){
		//Remove notification bar
		activity.getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
		
		//Remove title bar
		activity.getWindow().requestFeature(Window.FEATURE_NO_TITLE);
		
		 /*
         * //Remove title bar
		this.requestWindowFeature(Window.FEATURE_NO_TITLE);

		//Remove notification bar
		this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
         */
	}
	
	
	public static void hideKeyboard(IBinder windowToken){
		InputMethodManager imm = (InputMethodManager) context.getSystemService(Context.INPUT_METHOD_SERVICE);
		imm.hideSoftInputFromWindow(windowToken, 0);
	}
	
	/**
	 * Lauch default camera app
	 * @param withGallery Set true if you want to see thumnail icon on the camera app.
	 */
	public static void launchCameraApp(){
		Intent intent = new Intent();
		intent.setClassName("com.android.camera", "com.android.camera.Camera");
		intent.setAction(Intent.ACTION_MAIN);
		intent.addCategory(Intent.CATEGORY_LAUNCHER);
		
		String lastPhotoId = getLastPhotoTaken();
		if (!TextUtils.isEmpty(lastPhotoId)){
			try {
				//Uri photoUri = Uri.parse("content://media/external/images/" + lastPhotoId);
				Uri photoUri = Uri.parse(MediaStore.Images.Media.EXTERNAL_CONTENT_URI + "/" + lastPhotoId);
				
				//JLogUtils.debug("JAppUtils", "Media Exgterndal URI:" + MediaStore.Images.Media.EXTERNAL_CONTENT_URI);
				LogUtils.d("AppUtils", "Media Internal URI:" + MediaStore.Images.Media.INTERNAL_CONTENT_URI);
				intent.putExtra(MediaStore.EXTRA_OUTPUT, photoUri); 
			} catch (NullPointerException e){
				return;
			}
		}
		
		intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
		context.startActivity(intent);
	}
	
	public static String getLastPhotoTaken(){
		String[] projection = new String[]{MediaStore.Images.ImageColumns._ID,
	            MediaStore.Images.ImageColumns.DATA,
	            MediaStore.Images.ImageColumns.BUCKET_DISPLAY_NAME,
	            MediaStore.Images.ImageColumns.DATE_TAKEN
	    };
		
		ContentResolver cr = context.getContentResolver();
	    final Cursor cursor = cr.query(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, 
	                    projection, null, null, MediaStore.Images.ImageColumns.DATE_TAKEN + " DESC");
	    
	    if (cursor.moveToFirst()){
	    	return cursor.getString(0);
	    }

	    return null;
	}

	/**
	 * Lauch default gallery app
	 */
	public static void launchGalleryApp(){
		Intent intent = new Intent(Intent.ACTION_MAIN);
		intent.addCategory(Intent.CATEGORY_LAUNCHER);
		intent.setClassName("com.google.android.gallery3d", "com.android.gallery3d.app.Gallery");
		intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK);
		intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
		//intent.setClassName("com.android.camera", "com.android.camera.Camera");
		
		context.startActivity(intent);
	}
	
	/**
	 * Lauch default SMS app
	 */
	public static void launchSmsApp(){
		Intent intent = new Intent(Intent.ACTION_MAIN);
		intent.addCategory(Intent.CATEGORY_LAUNCHER);
		intent.setClassName("com.android.mms", "com.android.mms.ui.ConversationList");
		intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK);
		intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
		intent.setData(Uri.parse("sms:"));
		context.startActivity(intent);
	}
	
	//KeyEvent kev = new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_6);
	//onKeyDown(KeyEvent.KEYCODE_6, kev);     
	//public static void simulateKeyDown(Activity activity,  int keyCode) {
		//KeyEvent keyEvent = new KeyEvent(KeyEvent.ACTION_DOWN, keyCode);
		//keyEvent.dispatch(receiver, state, target);
	//}

}
